@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use experimental qw( isa signatures );
 
-our $VERSION = '0.012';
+our $VERSION = '0.013';
 
 use Mutex;
 use OpenTelemetry::Common;
@@ -95,7 +95,7 @@ sub _generate_otel_span_from_context {
         my $error = join ' - ', grep defined,
             @args{qw( message exception )};
 
-        $logger->error("OpenTelemetry error: $error");
+        $logger->error( "OpenTelemetry error: $error", $args{details} );
     };
 
     my $set = sub ( $new ) {
